Crate incodoc

Crate incodoc 

Modules

actions
output
parsing
reference_doc

Structs

CodeBlock
CodeBlock contains computer code.
CodeIdentError
Error to signal that the code was not formatted properly.
Date
Simple date: it is not checked if it actually exists on the calendar.
Doc
Document.
Emphasis
Emphasised or de-emphasised piece of text.
Heading
Heading, a title for the accompanying content.
IncodocParser
Parser for incodoc.
Link
Links are pieces of text with an accompanying URL.
List
Lists are fine-grained structure in a document.
Nav
Navigation structure has a description, sub-navigation structures and links to navigate to.
Paragraph
Paragraph is a grouping of content.
Section
A section is a heading followed by content that goes with it.
Table
Table contains rows of paragraphs.
TableRow
Tables contain rows of paragraphs
TextWithMeta
Text that has metadata: tags and/or properties.

Enums

CodeModeHint
Behavioural hint: the block hints what to do with the code.
DateError
DocItem
Document item.
EmOrText
EmStrength
Degree of emphasis or de-emphasis.
EmType
Whether it is an emphasis or de-emphasis.
ListType
ParagraphItem
Paragraphs can have content and further structure but no smaller sub-sections.
PropVal
Value properties can take.
PropValError
Error when no valid value could be parsed.
Rule
SectionItem
Section items are either paragraphs or sub-sections.

Type Aliases

Props
Properties metadata. Each property is a tuple of an identifier and a value.
Tags
Tags metadata. Each tag is a string.