pub trait GetTableOfContents {
// Required method
fn get_table_of_contents(
&self,
filter: &Option<(HashSet<TableOfContentsItemType>, TableOfContentsFilterType)>,
) -> Option<TableOfContentsItem>;
}Expand description
Generate a table of contents from a part of a document.
Required Methods
Sourcefn get_table_of_contents(
&self,
filter: &Option<(HashSet<TableOfContentsItemType>, TableOfContentsFilterType)>,
) -> Option<TableOfContentsItem>
fn get_table_of_contents( &self, filter: &Option<(HashSet<TableOfContentsItemType>, TableOfContentsFilterType)>, ) -> Option<TableOfContentsItem>
If a filter is supplied, an item must be of a type present in the filter to get included.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".